@@ -21,7 +21,7 @@ class AuthRememberBackend(object):
         utils.preset_cookie(request, token_string)
         token.delete()
 
-        user._remember_me_user = True
+        user._auth_remember_user = True
         return user
 
     def get_user(self, user_id):
